@@ -106,16 +106,16 @@ def __get_conn_data() -> dict[DbEngine, dict[DbParam, Any]]:
 _DB_CONN_DATA: Final[dict[DbEngine, dict[DbParam, Any]]] = __get_conn_data()
 
 
-def _assert_engine(errors: list[str] | None,
-                   engine: DbEngine) -> DbEngine:
+def _assert_engine(engine: DbEngine,
+                   errors: list[str] = None) -> DbEngine:
     """
     Verify if *engine* is in the list of configured engines.
 
     If *engine* is a configured engine, it is returned. If its value is *None*,
     the first engine in the list of configured engines (the default engine) is returned.
 
-    :param errors: incidental errors
     :param engine: the reference database engine
+    :param errors: incidental errors
     :return: the validated or default engine
     """
     # initialize the return valiable
@@ -132,23 +132,23 @@ def _assert_engine(errors: list[str] | None,
     return result
 
 
-def _assert_query_quota(errors: list[str] | None,
-                        engine: DbEngine,
+def _assert_query_quota(engine: DbEngine,
                         query: str,
                         where_vals: tuple | None,
                         count: int,
                         min_count: int | None,
-                        max_count: int | None) -> bool:
+                        max_count: int | None,
+                        errors: list[str] = None) -> bool:
     """
     Verify whether the number of tuples returned is compliant with the constraints specified.
 
-    :param errors: incidental error messages
     :param engine: the reference database engine
     :param query: the query statement used
     :param where_vals: the bind values used in the query
     :param count: the number of tuples returned
     :param min_count: optionally defines the minimum number of tuples to be returned
     :param max_count: optionally defines the maximum number of tuples to be returned
+    :param errors: incidental error messages
     :return: whether the number of tuples returned is compliant
     """
     # initialize the control message variable
