@@ -142,11 +142,11 @@ class DbConnectionPool:
     discarded, thus defeating the very purpose of the pool.
     """
     def __init__(self,
-                 errors: list[str] = None,
                  engine: DbEngine = None,
                  pool_size: int = None,
                  pool_timeout: int = None,
                  pool_recycle: int = None,
+                 errors: list[str] = None,
                  logger: Logger = None) -> None:
         """
         Construct a connection pool specific for the database provided in *engine*.
@@ -161,16 +161,16 @@ class DbConnectionPool:
 
         All instance attributes are final and should not be directly changed, lest the pool malfunction.
 
-        :param errors: incidental errors
         :param engine: the database engine to use (uses the default engine, if not provided)
         :param pool_size: number of connections to keep in the pool
         :param pool_timeout: number of seconds to wait for an available connection before failing
         :param pool_recycle: number of seconds after which connections in the pool are closed and reopened
+        :param errors: incidental error messages
         :param logger: optional logger
         """
         # make sure a configured databasee engine has been specified
-        engine = _assert_engine(errors=errors,
-                                engine=engine)
+        engine = _assert_engine(engine=engine,
+                                errors=errors)
 
         # obtain the default values for the pool parameters
         pool_params: dict[_PoolParam, Any] | None = None
@@ -219,7 +219,7 @@ class DbConnectionPool:
         """
         Obtain a pooled connection.
 
-        :param errors: incidental errors
+        :param errors: incidental error messages
         :param logger: optional logger
         :return: a connection from the pool, or *None* if error
         """
@@ -231,8 +231,8 @@ class DbConnectionPool:
         start: float = datetime.now(tz=UTC).timestamp()
         while not result:
             with self.stage_lock:
-                self.__revise(errors=errors,
-                              logger=logger)
+                self.__revise(logger=logger,
+                              errors=errors)
                 for conn_item in self.conn_data:
                     if conn_item[_ConnStage.AVAILABLE]:
                         conn_item[_ConnStage.AVAILABLE] = False
@@ -242,28 +242,28 @@ class DbConnectionPool:
                     match self.db_engine:
                         case DbEngine.MYSQL:
                             from . import mysql_pomes
-                            result = mysql_pomes.connect(errors=errors,
-                                                         autocommit=False,
+                            result = mysql_pomes.connect(autocommit=False,
+                                                         errors=errors,
                                                          logger=logger)
                         case DbEngine.ORACLE:
                             from . import oracle_pomes
-                            result = oracle_pomes.connect(errors=errors,
-                                                          autocommit=False,
+                            result = oracle_pomes.connect(autocommit=False,
+                                                          errors=errors,
                                                           logger=logger)
                         case DbEngine.POSTGRES:
                             from . import postgres_pomes
-                            result = postgres_pomes.connect(errors=errors,
-                                                            autocommit=False,
+                            result = postgres_pomes.connect(autocommit=False,
+                                                            errors=errors,
                                                             logger=logger)
                         case DbEngine.SQLSERVER:
                             from . import sqlserver_pomes
-                            result = sqlserver_pomes.connect(errors=errors,
-                                                             autocommit=False,
+                            result = sqlserver_pomes.connect(autocommit=False,
+                                                             errors=errors,
                                                              logger=logger)
                     if result:
-                        self.__act_on_event(errors=errors,
-                                            event=DbPoolEvent.CREATE,
+                        self.__act_on_event(event=DbPoolEvent.CREATE,
                                             conn=result,
+                                            errors=errors,
                                             logger=logger)
                         if not errors:
                             # store the connection
@@ -283,9 +283,9 @@ class DbConnectionPool:
                     break
 
         if result and not errors:
-            self.__act_on_event(errors=errors,
-                                event=DbPoolEvent.CHECKOUT,
+            self.__act_on_event(event=DbPoolEvent.CHECKOUT,
                                 conn=result,
+                                errors=errors,
                                 logger=logger)
 
         # a connection may have been found, but errors would prevent it from being used
@@ -333,14 +333,14 @@ class DbConnectionPool:
             self.event_stmts[event] = stmts
 
     def reclaim(self,
-                errors: list[str] | None,
                 conn: Any,
+                errors: list[str] = None,
                 logger: Logger = None) -> bool:
         """
         Reclaim the connection given in *conn*, allowing for its reuse.
 
-        :param errors: incidental errors
         :param conn: the connection to be reclaimed
+        :param errors: incidental error messages
         :param logger: optional logger
         :return: *True* if *conn* was successfully reclaimed, *False* otherwise
         """
@@ -351,9 +351,9 @@ class DbConnectionPool:
         with self.stage_lock:
             for data in self.conn_data:
                 if data[_ConnStage.CONNECTION] == conn:
-                    self.__act_on_event(errors=errors,
-                                        event=DbPoolEvent.CHECKIN,
+                    self.__act_on_event(event=DbPoolEvent.CHECKIN,
                                         conn=conn,
+                                        errors=errors,
                                         logger=logger)
                     if not errors:
                         data[_ConnStage.AVAILABLE] = True
@@ -385,10 +385,10 @@ class DbConnectionPool:
             logger.debug(msg=f"{self.db_engine} pool terminated")
 
     def __act_on_event(self,
-                       errors: list[str] | None,
                        event: DbPoolEvent,
                        conn: Any,
-                       logger: Logger | None) -> None:
+                       errors: list[str] = None,
+                       logger: Logger = None) -> None:
         """
         Act on *event*, by invoking the hooked callback function, and/or executing the registered SQL statements.
 
@@ -405,9 +405,9 @@ class DbConnectionPool:
         If the callback function adds content to *errors*, then the next step
         (execution of the registered SQL statements) is skipped.
 
-        :param errors: incidental errors
         :param event: the reference event
         :param conn: the reference connection
+        :param errors: incidental error messages
         :param logger: optionqal logger
         """
         if not isinstance(errors, list):
@@ -416,21 +416,20 @@ class DbConnectionPool:
             # invoke the callback
             callback: callable = self.event_callbacks[event]
             if callback:
-                callback(errors=errors,
-                         connection=conn,
+                callback(connection=conn,
+                         errors=errors,
                          logger=logger)
                 if logger:
                     logger.debug(msg=f"Event '{event}' on connection '{conn}': "
                                      f"callback '{callback}', {len(errors)} errors")
-
             # execute the statements
             if not errors and self.event_stmts[event]:
                 from . import db_pomes
                 for stmt in self.event_stmts[event]:
-                    db_pomes.db_execute(errors=errors,
-                                        exc_stmt=stmt,
+                    db_pomes.db_execute(exc_stmt=stmt,
                                         engine=self.db_engine,
                                         connection=conn,
+                                        errors=errors,
                                         logger=logger)
                     if logger:
                         logger.debug(msg=f"Event '{event}' on connection '{conn}': "
@@ -439,8 +438,8 @@ class DbConnectionPool:
                         break
 
     def __revise(self,
-                 errors: list[str] | None,
-                 logger: Logger | None) -> None:
+                 errors: list[str] = None,
+                 logger: Logger = None) -> None:
         """
         Revise the pool, reclaiming or disposing of connections, if applicable.
 
@@ -460,9 +459,9 @@ class DbConnectionPool:
                 # connect exausted its lifetime
                 if data[_ConnStage.TIMESTAMP] + self.pool_recycle > datetime.now(tz=UTC):
                     # close the connection
-                    self.__act_on_event(errors=errors,
-                                        event=DbPoolEvent.CLOSE,
+                    self.__act_on_event(event=DbPoolEvent.CLOSE,
                                         conn=data[_ConnStage.CONNECTION],
+                                        errors=errors,
                                         logger=logger)
                     with suppress(Exception):
                         data[_ConnStage.CONNECTION].close()
@@ -474,9 +473,9 @@ class DbConnectionPool:
             # with only 2 references (1 held here, and 1 held by the pool), connection is no longer in use
             elif getrefcount(data[_ConnStage.CONNECTION]) < 3:
                 # reclaim the connection
-                self.__act_on_event(errors=errors,
-                                    event=DbPoolEvent.CHECKIN,
+                self.__act_on_event(event=DbPoolEvent.CHECKIN,
                                     conn=data[_ConnStage.CONNECTION],
+                                    errors=errors,
                                     logger=logger)
                 if not errors:
                     data[_ConnStage.AVAILABLE] = True
@@ -496,8 +495,7 @@ def db_get_pool(engine: DbEngine = None) -> DbConnectionPool | None:
     result: DbConnectionPool | None = None
 
     # assert the database engine
-    engine = _assert_engine(errors=None,
-                            engine=engine)
+    engine = _assert_engine(engine=engine)
     if engine:
         with _instances_lock:
             result = _POOL_INSTANCES.get(engine)
@@ -518,14 +516,12 @@ def db_pool_acquire(engine: DbEngine = None,
     result: Any = None
 
     # assert the database engine
-    engine = _assert_engine(errors=None,
-                            engine=engine)
+    engine = _assert_engine(engine=engine)
     if engine:
         pool: DbConnectionPool = db_get_pool(engine=engine)
         # obtain the pooled connection
         if pool:
-            result = pool.connect(errors=None,
-                                  logger=logger)
+            result = pool.connect(logger=logger)
     return result
 
 
@@ -544,13 +540,11 @@ def db_pool_release(conn: Any,
     result: bool = False
 
     # assert the database engine
-    engine = _assert_engine(errors=None,
-                            engine=engine)
+    engine = _assert_engine(engine=engine)
     if engine:
         # reclaim the connection
         pool: DbConnectionPool = db_get_pool(engine=engine)
         if pool:
-            result = pool.reclaim(errors=None,
-                                  conn=conn,
+            result = pool.reclaim(conn=conn,
                                   logger=logger)
     return result
