@@ -8,8 +8,7 @@ from .db_common import DbEngine, _assert_engine, _except_msg
 from .db_pomes import db_connect, db_close
 
 
-def db_stream_data(errors: list[str] | None,
-                   table: str,
+def db_stream_data(table: str,
                    columns: list[str],
                    engine: DbEngine = None,
                    connection: Any = None,
@@ -20,6 +19,7 @@ def db_stream_data(errors: list[str] | None,
                    limit_count: int = None,
                    batch_size_in: int = None,
                    batch_size_out: int = None,
+                   errors: list[str] = None,
                    logger: Logger = None) -> int | None:
     """
     Stream data from a database table.
@@ -36,7 +36,6 @@ def db_stream_data(errors: list[str] | None,
     The parameter *committable* is relevant only if *connection* is provided, and is otherwise ignored.
     A rollback is always attempted, if an error occurs.
 
-    :param errors: incidental error messages
     :param table: the possibly schema-qualified table to read the data from
     :param columns: the table columns to stream
     :param engine: the database engine to use (uses the default engine, if not provided)
@@ -48,6 +47,7 @@ def db_stream_data(errors: list[str] | None,
     :param limit_count: maximum number of tuples to migrate (defaults to no limit)
     :param batch_size_in: maximum number of tuples to read in each batch (defaults to no limit)
     :param batch_size_out: maximum number of tuples to stream in each batch (defaults to no limit)
+    :param errors: incidental error messages
     :param logger: optional logger
     :return: the number of tuples effectively streamed, or *None* if error
     """
@@ -58,14 +58,14 @@ def db_stream_data(errors: list[str] | None,
     op_errors: list[str] = []
 
     # assert the database engine
-    engine = _assert_engine(errors=op_errors,
-                            engine=engine)
+    engine = _assert_engine(engine=engine,
+                            errors=op_errors)
 
     # make sure to have a connection to the source database
     curr_conn: Any = None
     if engine:
-        curr_conn = connection or db_connect(errors=op_errors,
-                                             engine=engine,
+        curr_conn = connection or db_connect(engine=engine,
+                                             errors=op_errors,
                                              logger=logger)
     if curr_conn:
         # normalize these parameters
@@ -200,8 +200,7 @@ def db_stream_data(errors: list[str] | None,
     return result
 
 
-def db_stream_lobs(errors: list[str] | None,
-                   table: str,
+def db_stream_lobs(table: str,
                    lob_column: str,
                    pk_columns: list[str] = None,
                    ret_column: str = None,
@@ -214,6 +213,7 @@ def db_stream_lobs(errors: list[str] | None,
                    limit_count: int = None,
                    batch_size: int = None,
                    chunk_size: int = None,
+                   errors: list[str] = None,
                    logger: Logger = None,
                    log_trigger: int = 10000) -> None:
     """
@@ -237,7 +237,6 @@ def db_stream_lobs(errors: list[str] | None,
     The parameter *committable* is relevant only if *connection* is provided, and is otherwise ignored.
     A rollback is always attempted, if an error occurs.
 
-    :param errors: incidental error messages
     :param table: the table holding the LOBs
     :param lob_column: the column holding the LOB
     :param pk_columns: columns making up a primary key, or a unique identifier for a tuple, in database
@@ -251,6 +250,7 @@ def db_stream_lobs(errors: list[str] | None,
     :param limit_count: maximum number of tuples to migrate (defaults to no limit)
     :param batch_size: maximum number of tuples to read in each batch (defaults to no limit)
     :param chunk_size: size in bytes of the data chunk to read/write (defaults to no limit)
+    :param errors: incidental error messages
     :param logger: optional logger
     :param log_trigger: number of tuples to trigger logging info on migration (defaults to 10000 tuples)
     """
@@ -258,14 +258,14 @@ def db_stream_lobs(errors: list[str] | None,
     op_errors: list[str] = []
 
     # assert the database engine
-    engine = _assert_engine(errors=op_errors,
-                            engine=engine)
+    engine = _assert_engine(engine=engine,
+                            errors=op_errors)
 
     # make sure to have a connection to the source database
     curr_conn: Any = None
     if engine:
-        curr_conn = connection or db_connect(errors=op_errors,
-                                             engine=engine,
+        curr_conn = connection or db_connect(engine=engine,
+                                             errors=op_errors,
                                              logger=logger)
     if curr_conn:
         # normalize these parameters
