@@ -8,12 +8,12 @@ from .db_common import (
 from .db_pomes import db_execute, db_select
 
 
-def db_create_session_table(errors: list[str] | None,
-                            engine: DbEngine,
+def db_create_session_table(engine: DbEngine,
                             connection: Any,
                             table_name: str,
                             column_data: list[str],
-                            logger: Logger) -> None:
+                            errors: list[str] = None,
+                            logger: Logger = None) -> None:
     """
     Create the session-scoped table *table_name*, with the list of columns specifications in *column_data*.
 
@@ -29,16 +29,16 @@ def db_create_session_table(errors: list[str] | None,
     For *SQLServer*, session-scoped temporary table names must start with the hash symbol *#*, an error
     being raised if otherwise.
 
-    :param errors: incidental error messages
     :param engine: the reference database engine
     :param connection: the connection defining the session
     :param table_name: the, possibly schema-qualified, name of the table to be created
     :param column_data: this list of column information for the table cration
+    :param errors: incidental error messages
     :param logger: optional logger
     """
     # assert the database engine
-    engine = _assert_engine(errors=errors,
-                            engine=engine)
+    engine = _assert_engine(engine=engine,
+                            errors=errors)
     if engine:
         stmt: str | None = None
         match engine:
@@ -60,9 +60,9 @@ def db_create_session_table(errors: list[str] | None,
                     # 'ON COMMIT PRESERVE DEFINITION' ensures the table lasts for the session
                     stmt = (f"CREATE PRIVATE TEMPORARY TABLE {table_name.upper()} "
                             f"({', '.join(column_data)}) ON COMMIT PRESERVE DEFINITION")
-                elif not db_table_exists(errors=errors,
-                                         table_name=table_name,
+                elif not db_table_exists(table_name=table_name,
                                          engine=DbEngine.ORACLE,
+                                         errors=errors,
                                          logger=logger) and not errors:
                     # - the table definition remains in the database permanently, but the data is session-specific
                     # - 'ON COMMIT PRESERVE ROWS' keeps data for the entire session
@@ -73,10 +73,10 @@ def db_create_session_table(errors: list[str] | None,
                 stmt = f"CREATE TABLE {table_name} ({', '.join(column_data)})"
 
         if stmt:
-            db_execute(errors=errors,
-                       exc_stmt=stmt,
+            db_execute(exc_stmt=stmt,
                        engine=engine,
                        connection=connection,
+                       errors=errors,
                        logger=logger)
 
 
@@ -107,11 +107,11 @@ def db_get_session_table_prefix(engine: DbEngine) -> str:
     return result
 
 
-def db_get_tables(errors: list[str] | None,
-                  schema: str = None,
+def db_get_tables(schema: str = None,
                   engine: DbEngine = None,
                   connection: Any = None,
                   committable: bool = None,
+                  errors: list[str] = None,
                   logger: Logger = None) -> list[str] | None:
     """
     Retrieve the list of schema-qualified tables in the database.
@@ -119,11 +119,11 @@ def db_get_tables(errors: list[str] | None,
     The parameter *committable* is relevant only if *connection* is provided, and is otherwise ignored.
     A rollback is always attempted, if an error occurs.
 
-    :param errors: incidental error messages
     :param schema: optional name of the schema to restrict the search to
     :param engine: the database engine to use (uses the default engine, if not provided)
     :param connection: optional connection to use (obtains a new one, if not provided)
     :param committable: whether to commit operation on errorless completion
+    :param errors: incidental error messages
     :param logger: optional logger
     :return: the schema-qualified table names found, or *None* if error
     """
@@ -134,8 +134,8 @@ def db_get_tables(errors: list[str] | None,
     op_errors: list[str] = []
 
     # assert the database engine
-    engine = _assert_engine(errors=op_errors,
-                            engine=engine)
+    engine = _assert_engine(engine=engine,
+                            errors=op_errors)
     if engine:
         # build the query
         if engine == DbEngine.ORACLE:
@@ -150,11 +150,11 @@ def db_get_tables(errors: list[str] | None,
                 sel_stmt += f" AND LOWER(table_schema) = '{schema.lower()}'"
 
         # execute the query
-        recs: list[tuple[str]] = db_select(errors=op_errors,
-                                           sel_stmt=sel_stmt,
+        recs: list[tuple[str]] = db_select(sel_stmt=sel_stmt,
                                            engine=engine,
                                            connection=connection,
                                            committable=committable,
+                                           errors=op_errors,
                                            logger=logger)
         # process the query result
         if not op_errors:
@@ -167,11 +167,11 @@ def db_get_tables(errors: list[str] | None,
     return result
 
 
-def db_table_exists(errors: list[str] | None,
-                    table_name: str,
+def db_table_exists(table_name: str,
                     engine: DbEngine = None,
                     connection: Any = None,
                     committable: bool = None,
+                    errors: list[str] = None,
                     logger: Logger = None) -> bool | None:
     """
     Determine whether the table *table_name* exists in the database.
@@ -180,11 +180,11 @@ def db_table_exists(errors: list[str] | None,
     The parameter *committable* is relevant only if *connection* is provided, and is otherwise ignored.
     A rollback is always attempted, if an error occurs.
 
-    :param errors: incidental error messages
     :param table_name: the, possibly schema-qualified, name of the table to look for
     :param engine: the database engine to use (uses the default engine, if not provided)
     :param connection: optional connection to use (obtains a new one, if not provided)
     :param committable: whether to commit operation on errorless completion
+    :param errors: incidental error messages
     :param logger: optional logger
     :return: *True* if the table was found, *False* otherwise, or *None* if error
     """
@@ -195,8 +195,8 @@ def db_table_exists(errors: list[str] | None,
     op_errors: list[str] = []
 
     # assert the database engine
-    engine = _assert_engine(errors=op_errors,
-                            engine=engine)
+    engine = _assert_engine(engine=engine,
+                            errors=op_errors)
     if engine:
         # determine the table schema
         table_schema: str
@@ -217,11 +217,11 @@ def db_table_exists(errors: list[str] | None,
                 sel_stmt += f" AND LOWER(table_schema) = '{table_schema.lower()}'"
 
         # execute the query
-        recs: list[tuple[int]] = db_select(errors=op_errors,
-                                           sel_stmt=sel_stmt,
+        recs: list[tuple[int]] = db_select(sel_stmt=sel_stmt,
                                            engine=engine,
                                            connection=connection,
                                            committable=committable,
+                                           errors=op_errors,
                                            logger=logger)
         # process the query result
         if not op_errors:
@@ -234,11 +234,11 @@ def db_table_exists(errors: list[str] | None,
     return result
 
 
-def db_drop_table(errors: list[str] | None,
-                  table_name: str,
+def db_drop_table(table_name: str,
                   engine: DbEngine = None,
                   connection: Any = None,
                   committable: bool = None,
+                  errors: list[str] = None,
                   logger: Logger = None) -> None:
     """
     Drop the table given by the, possibly schema-qualified, *table_name*.
@@ -250,19 +250,19 @@ def db_drop_table(errors: list[str] | None,
     The parameter *committable* is relevant only if *connection* is provided, and is otherwise ignored.
     A rollback is always attempted, if an error occurs.
 
-    :param errors: incidental error messages
     :param table_name: the, possibly schema-qualified, name of the table to drop
     :param engine: the database engine to use (uses the default engine, if not provided)
     :param connection: optional connection to use (obtains a new one, if not provided)
     :param committable: whether to commit operation on errorless completion
+    :param errors: incidental error messages
     :param logger: optional logger
     """
     # initialize the local errors list
     op_errors: list[str] = []
 
     # assert the database engine
-    engine = _assert_engine(errors=op_errors,
-                            engine=engine)
+    engine = _assert_engine(engine=engine,
+                            errors=op_errors)
     if engine:
         # build the DROP statement
         if engine == DbEngine.ORACLE:
@@ -292,11 +292,11 @@ def db_drop_table(errors: list[str] | None,
             drop_stmt: str = f"DROP TABLE IF EXISTS {table_name}"
 
         # drop the table
-        db_execute(errors=op_errors,
-                   exc_stmt=drop_stmt,
+        db_execute(exc_stmt=drop_stmt,
                    engine=engine,
                    connection=connection,
                    committable=committable,
+                   errors=op_errors,
                    logger=logger)
 
     # acknowledge local errors
@@ -304,11 +304,11 @@ def db_drop_table(errors: list[str] | None,
         errors.extend(op_errors)
 
 
-def db_get_table_columns(errors: list[str] | None,
-                         table_name: str,
+def db_get_table_columns(table_name: str,
                          engine: DbEngine = None,
                          connection: Any = None,
                          committable: bool = None,
+                         errors: list[str] = None,
                          logger: Logger = None) -> list[tuple[str, str, bool]] | None:
     """
     Retrieve all columns in *table_name*, along with their respective data types and nullabilities.
@@ -316,11 +316,11 @@ def db_get_table_columns(errors: list[str] | None,
     The parameter *committable* is relevant only if *connection* is provided, and is otherwise ignored.
     A rollback is always attempted, if an error occurs.
 
-    :param errors: incidental error messages
     :param table_name: the possibly schema-qualified name of the table
     :param engine: the database engine to use (uses the default engine, if not provided)
     :param connection: optional connection to use (obtains a new one, if not provided)
     :param committable: whether to commit operation on errorless completion
+    :param errors: incidental error messages
     :param logger: optional logger
     :return: a list of tuples with names, types and the nullability state of all columns in *table_name*
     """
@@ -331,8 +331,8 @@ def db_get_table_columns(errors: list[str] | None,
     op_errors: list[str] = []
 
     # assert the database engine
-    engine = _assert_engine(errors=op_errors,
-                            engine=engine)
+    engine = _assert_engine(engine=engine,
+                            errors=op_errors)
     if engine:
         # determine the table schema
         table_schema: str
@@ -361,12 +361,12 @@ def db_get_table_columns(errors: list[str] | None,
 
         # execute the query
         # noinspection PyTypeChecker
-        recs: list[tuple[str, str, str]] = db_select(errors=op_errors,
-                                                     sel_stmt=sel_stmt,
+        recs: list[tuple[str, str, str]] = db_select(sel_stmt=sel_stmt,
                                                      where_data=where_data,
                                                      engine=engine,
                                                      connection=connection,
                                                      committable=committable,
+                                                     errors=op_errors,
                                                      logger=logger)
         # process the query result
         if not op_errors and recs:
@@ -379,11 +379,11 @@ def db_get_table_columns(errors: list[str] | None,
     return result
 
 
-def db_get_table_ddl(errors: list[str] | None,
-                     table_name: str,
+def db_get_table_ddl(table_name: str,
                      engine: DbEngine = None,
                      connection: Any = None,
                      committable: bool = None,
+                     errors: list[str] = None,
                      logger: Logger = None) -> str | None:
     """
     Retrieve the DDL script used to create the table *table_name*.
@@ -395,11 +395,11 @@ def db_get_table_ddl(errors: list[str] | None,
     The parameter *committable* is relevant only if *connection* is provided, and is otherwise ignored.
     A rollback is always attempted, if an error occurs.
 
-    :param errors: incidental error messages
     :param table_name: the schema-qualified name of the table
     :param engine: the database engine to use (uses the default engine, if not provided)
     :param connection: optional connection to use (obtains a new one, if not provided)
     :param committable: whether to commit operation on errorless completion
+    :param errors: incidental error messages
     :param logger: optional logger
     :return: the DDL script used to create the index, or *None* if error or the index does not exist
     """
@@ -410,8 +410,8 @@ def db_get_table_ddl(errors: list[str] | None,
     op_errors: list[str] = []
 
     # assert the database engine
-    engine = _assert_engine(errors=op_errors,
-                            engine=engine)
+    engine = _assert_engine(engine=engine,
+                            errors=op_errors)
     if engine:
         # determine the table schema
         table_schema: str
@@ -435,11 +435,11 @@ def db_get_table_ddl(errors: list[str] | None,
                             f"'{table_schema.lower()}.{table_name.upper()}'))")
 
             # execute the query
-            recs: list[tuple[str]] = db_select(errors=op_errors,
-                                               sel_stmt=sel_stmt,
+            recs: list[tuple[str]] = db_select(sel_stmt=sel_stmt,
                                                engine=engine,
                                                connection=connection,
                                                committable=committable,
+                                               errors=op_errors,
                                                logger=logger)
             # process the query result
             if not op_errors and recs:
